@@ -1,7 +1,7 @@
 /*
  * RemotePlugin.h - base class providing RPC like mechanisms
  *
- * Copyright (c) 2008-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2008-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -26,8 +26,8 @@
 #define _REMOTE_PLUGIN_H
 
 #include "export.h"
-#include "midi.h"
-#include "VST_sync_shm.h"
+#include "MidiEvent.h"
+#include "VstSyncData.h"
 
 #include <vector>
 #include <cstdio>
@@ -52,7 +52,7 @@
 #include <process.h>
 #endif
 
-#include <Qt/qglobal.h>
+#include <QtCore/QtGlobal>
 
 #if QT_VERSION >= 0x040400
 #include <QtCore/QSystemSemaphore>
@@ -75,7 +75,7 @@
 
 #ifdef USE_QT_SHMEM
 
-#include <Qt/qglobal.h>
+#include <QtCore/QtGlobal>
 
 #if QT_VERSION >= 0x040400
 #include <QtCore/QSharedMemory>
@@ -474,7 +474,6 @@ private:
 #else
 	int m_shmID;
 #endif
-	size_t m_shmSize;
 	shmData * m_data;
 #ifdef USE_QT_SEMAPHORES
 	QSystemSemaphore m_dataSem;
@@ -724,7 +723,7 @@ public:
 
 	bool process( const sampleFrame * _in_buf, sampleFrame * _out_buf );
 
-	void processMidiEvent( const midiEvent &, const f_cnt_t _offset );
+	void processMidiEvent( const MidiEvent&, const f_cnt_t _offset );
 
 	void updateSampleRate( sample_rate_t _sr )
 	{
@@ -780,7 +779,6 @@ private:
 	void resizeSharedProcessingMemory();
 
 
-	bool m_initialized;
 	bool m_failed;
 
 	QProcess m_process;
@@ -813,15 +811,14 @@ public:
 	RemotePluginClient( key_t _shm_in, key_t _shm_out );
 	virtual ~RemotePluginClient();
 #ifdef USE_QT_SHMEM
-	sncVST * getQtVSTshm();
+	VstSyncData * getQtVSTshm();
 #endif
 	virtual bool processMessage( const message & _m );
 
 	virtual void process( const sampleFrame * _in_buf,
 					sampleFrame * _out_buf ) = 0;
 
-	virtual void processMidiEvent( const midiEvent &,
-						const f_cnt_t /* _offset */ )
+	virtual void processMidiEvent( const MidiEvent&, const f_cnt_t /* _offset */ )
 	{
 	}
 
@@ -884,7 +881,7 @@ private:
 	QSharedMemory m_shmObj;
 	QSharedMemory m_shmQtID;
 #endif
-	sncVST * m_SncVSTplug;
+	VstSyncData * m_vstSyncData;
 	float * m_shm;
 
 	int m_inputCount;
@@ -1014,7 +1011,7 @@ RemotePluginClient::RemotePluginClient( key_t _shm_in, key_t _shm_out ) :
 	m_shmObj(),
 	m_shmQtID( "/usr/bin/lmms" ),
 #endif
-	m_SncVSTplug( NULL ),
+	m_vstSyncData( NULL ),
 	m_shm( NULL ),
 	m_inputCount( 0 ),
 	m_outputCount( 0 ),
@@ -1024,9 +1021,9 @@ RemotePluginClient::RemotePluginClient( key_t _shm_in, key_t _shm_out ) :
 #ifdef USE_QT_SHMEM
 	if( m_shmQtID.attach( QSharedMemory::ReadOnly ) )
 	{
-		m_SncVSTplug = (sncVST *) m_shmQtID.data();
-		m_bufferSize = m_SncVSTplug->m_bufferSize;
-		m_sampleRate = m_SncVSTplug->m_sampleRate;
+		m_vstSyncData = (VstSyncData *) m_shmQtID.data();
+		m_bufferSize = m_vstSyncData->m_bufferSize;
+		m_sampleRate = m_vstSyncData->m_sampleRate;
 		return;
 	}
 #else
@@ -1045,18 +1042,18 @@ RemotePluginClient::RemotePluginClient( key_t _shm_in, key_t _shm_out ) :
 		}
 		else
 		{	// attach segment
-			m_SncVSTplug = (sncVST *)shmat(m_shmID, 0, 0);
-			if( m_SncVSTplug == (sncVST *)( -1 ) )
+			m_vstSyncData = (VstSyncData *)shmat(m_shmID, 0, 0);
+			if( m_vstSyncData == (VstSyncData *)( -1 ) )
 			{
 				perror( "RemotePluginClient::shmat" );
 			}
 			else
 			{
-				m_bufferSize = m_SncVSTplug->m_bufferSize;
-				m_sampleRate = m_SncVSTplug->m_sampleRate;
+				m_bufferSize = m_vstSyncData->m_bufferSize;
+				m_sampleRate = m_vstSyncData->m_sampleRate;
 
 				// detach segment
-				if( shmdt(m_SncVSTplug) == -1 )
+				if( shmdt(m_vstSyncData) == -1 )
 				{
 					perror("RemotePluginClient::shmdt");
 				}
@@ -1088,9 +1085,9 @@ RemotePluginClient::~RemotePluginClient()
 
 
 #ifdef USE_QT_SHMEM
-sncVST * RemotePluginClient::getQtVSTshm()
+VstSyncData * RemotePluginClient::getQtVSTshm()
 {
-	return m_SncVSTplug;
+	return m_vstSyncData;
 }
 #endif
 
@@ -1120,7 +1117,7 @@ bool RemotePluginClient::processMessage( const message & _m )
 
 		case IdMidiEvent:
 			processMidiEvent(
-				midiEvent( static_cast<MidiEventTypes>(
+				MidiEvent( static_cast<MidiEventTypes>(
 							_m.getInt( 0 ) ),
 						_m.getInt( 1 ),
 						_m.getInt( 2 ),
