@@ -1,7 +1,7 @@
 /*
- * flp_import.cpp - support for importing FLP-files
+ * FlpImport.cpp - support for importing FLP-files
  *
- * Copyright (c) 2006-2009 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2006-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -29,7 +29,7 @@
 #include <QtCore/QBuffer>
 
 #include "FlpImport.h"
-#include "note_play_handle.h"
+#include "NotePlayHandle.h"
 #include "AutomationPattern.h"
 #include "basic_filters.h"
 #include "bb_track.h"
@@ -51,7 +51,7 @@
 #include "ProjectJournal.h"
 #include "project_notes.h"
 #include "song.h"
-#include "track_container.h"
+#include "TrackContainer.h"
 #include "embed.h"
 #include "lmmsconfig.h"
 
@@ -224,6 +224,9 @@ enum FLP_Events
 	FLP_Text_ChanGroupName	= FLP_Text + 39,
 	FLP_Text_PlayListItems	= FLP_Text + 41,
 
+	FLP_Event_EffectParams = 225,
+	FLP_Event_PlaylistItems = 233,
+
 	FLP_CmdCount
 
 } ;
@@ -461,7 +464,7 @@ struct FL_Channel : public FL_Plugin
 		filterCut( 10000 ),
 		filterRes( 0.1 ),
 		filterEnabled( false ),
-		arpDir( Arpeggiator::ArpDirUp ),
+		arpDir( InstrumentFunctionArpeggio::ArpDirUp ),
 		arpRange( 0 ),
 		selectedArp( 0 ),
 		arpTime( 100 ),
@@ -586,7 +589,7 @@ FlpImport::~FlpImport()
 
 
 
-bool FlpImport::tryImport( trackContainer * _tc )
+bool FlpImport::tryImport( TrackContainer* tc )
 {
 	const int mappedFilter[] =
 	{
@@ -600,14 +603,14 @@ bool FlpImport::tryImport( trackContainer * _tc )
 		basicFilters<>::NumFilters+basicFilters<>::LowPass
 	} ;
 
-	const Arpeggiator::ArpDirections mappedArpDir[] =
+	const InstrumentFunctionArpeggio::ArpDirections mappedArpDir[] =
 	{
-		Arpeggiator::ArpDirUp,
-		Arpeggiator::ArpDirUp,
-		Arpeggiator::ArpDirDown,
-		Arpeggiator::ArpDirUpAndDown,
-		Arpeggiator::ArpDirUpAndDown,
-		Arpeggiator::ArpDirRandom
+		InstrumentFunctionArpeggio::ArpDirUp,
+		InstrumentFunctionArpeggio::ArpDirUp,
+		InstrumentFunctionArpeggio::ArpDirDown,
+		InstrumentFunctionArpeggio::ArpDirUpAndDown,
+		InstrumentFunctionArpeggio::ArpDirUpAndDown,
+		InstrumentFunctionArpeggio::ArpDirRandom
 	} ;
 
 	QMap<QString, int> mappedPluginTypes;
@@ -711,9 +714,9 @@ bool FlpImport::tryImport( trackContainer * _tc )
 	}
 
 	QProgressDialog progressDialog(
-			trackContainer::tr( "Importing FLP-file..." ),
-			trackContainer::tr( "Cancel" ), 0, p.numChannels );
-	progressDialog.setWindowTitle( trackContainer::tr( "Please wait..." ) );
+			TrackContainer::tr( "Importing FLP-file..." ),
+			TrackContainer::tr( "Cancel" ), 0, p.numChannels );
+	progressDialog.setWindowTitle( TrackContainer::tr( "Please wait..." ) );
 	progressDialog.show();
 
 	bool valid = false;
@@ -721,7 +724,7 @@ bool FlpImport::tryImport( trackContainer * _tc )
 	// search for FLdt chunk
 	while( 1 )
 	{
-		Sint32 id = readID();
+		int32_t id = readID();
 		const int len = read32LE();
 		if( file().atEnd() )
 		{
@@ -769,7 +772,7 @@ bool FlpImport::tryImport( trackContainer * _tc )
 	while( file().atEnd() == false )
 	{
 		FLP_Events ev = static_cast<FLP_Events>( readByte() );
-		Uint32 data = readByte();
+		uint32_t data = readByte();
 
 		if( ev >= FLP_Word && ev < FLP_Text )
 		{
@@ -786,7 +789,7 @@ bool FlpImport::tryImport( trackContainer * _tc )
 		if( ev >= FLP_Text )
 		{
 			text_len = data & 0x7F;
-			Uint8 shift = 0;
+			uint8_t shift = 0;
 			while( data & 0x80 )
 			{
 				data = readByte();
@@ -977,6 +980,7 @@ if( p.currentEffectChannel <= NumFxChannels )
 
 			case FLP_LayerChans:
 				p.channels[data].layerParent = cur_channel;
+				break;
 
 			// DWORD EVENTS
 			case FLP_Color:
@@ -1330,7 +1334,7 @@ if( p.currentEffectChannel <= NumFxChannels )
 			// case 216: pi[2] /= p.versionSpecificFactor
 			// case 229: pi[1] /= p.versionSpecificFactor
 
-			case 225:
+			case FLP_Event_EffectParams:
 			{
 				enum FLP_EffectParams
 				{
@@ -1361,7 +1365,7 @@ qDebug( "FX-ch: %d  param: %x  value:%x\n", ch, param, val );
 				break;
 			}
 
-			case 233:	// playlist items
+			case FLP_Event_PlaylistItems:	// playlist items
 			{
 				const int bpi = 28;
 				const int imax = text_len / bpi;
@@ -1516,7 +1520,7 @@ else
 			}
 		}
 
-		Arpeggiator * arp = &t->m_arpeggiator;
+		InstrumentFunctionArpeggio * arp = &t->m_arpeggio;
 		arp->m_arpDirectionModel.setValue( it->arpDir );
 		arp->m_arpRangeModel.setValue( it->arpRange );
 		arp->m_arpModel.setValue( it->selectedArp );
@@ -1741,8 +1745,7 @@ p->putValue( jt->pos, value, false );
 		{
 			continue;
 		}
-		trackContentObject * tco =
-			bb_tracks[it->pattern]->createTCO( midiTime() );
+		trackContentObject * tco = bb_tracks[it->pattern]->createTCO( MidiTime() );
 		tco->movePosition( it->position );
 		if( it->length != DefaultTicksPerTact )
 		{
@@ -1814,7 +1817,7 @@ void FlpImport::processPluginParams( FL_Channel * _ch )
 			int ws = Oscillator::UserDefinedWave;
 			for( int i = 0; i < 3; ++i )
 			{
-				const Sint32 * d = (const Sint32 *)
+				const int32_t * d = (const int32_t *)
 					( _ch->pluginSettings + i * 28 );
 				QString is = QString::number( i );
 				de.setAttribute( "vol" + is,
