@@ -1,7 +1,7 @@
 /*
  * RemoteVstPlugin.cpp - LMMS VST Support Layer (RemotePlugin client)
  *
- * Copyright (c) 2005-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -89,10 +89,10 @@ struct ERect
 
 
 #include "lmms_basics.h"
-#include "midi.h"
+#include "Midi.h"
 #include "communication.h"
 
-#include "VST_sync_shm.h"
+#include "VstSyncData.h"
 
 #ifdef LMMS_BUILD_WIN32
 #define USE_QT_SHMEM
@@ -132,8 +132,7 @@ public:
 	virtual void process( const sampleFrame * _in, sampleFrame * _out );
 
 
-	virtual void processMidiEvent( const midiEvent & _event,
-							const f_cnt_t _offset );
+	virtual void processMidiEvent( const MidiEvent& event, const f_cnt_t offset );
 
 	// set given sample-rate for plugin
 	virtual void updateSampleRate()
@@ -297,7 +296,7 @@ private:
 
 	AEffect * m_plugin;
 	HWND m_window;
-	Sint32 m_windowID;
+	intptr_t m_windowID;
 	int m_windowWidth;
 	int m_windowHeight;
 
@@ -326,7 +325,7 @@ private:
 	in * m_in;
 
 	int m_shmID;
-	sncVST * m_SncVSTplug;
+	VstSyncData* m_vstSyncData;
 
 } ;
 
@@ -352,7 +351,7 @@ RemoteVstPlugin::RemoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
 	m_currentProgram( -1 ),
 	m_in( NULL ),
 	m_shmID( -1 ),
-	m_SncVSTplug( NULL )
+	m_vstSyncData( NULL )
 
 {
 	pthread_mutex_init( &m_pluginLock, NULL );
@@ -373,29 +372,29 @@ RemoteVstPlugin::RemoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
 		}
 		else
 		{	// attach segment
-			m_SncVSTplug = (sncVST *)shmat(m_shmID, 0, 0);
-			if( m_SncVSTplug == (sncVST *)( -1 ) )
+			m_vstSyncData = (VstSyncData *)shmat(m_shmID, 0, 0);
+			if( m_vstSyncData == (VstSyncData *)( -1 ) )
 			{
 				perror( "RemoteVstPlugin.cpp::shmat" );
 			}
 		}
 	}
 #else
-	m_SncVSTplug = RemotePluginClient::getQtVSTshm();
+	m_vstSyncData = RemotePluginClient::getQtVSTshm();
 #endif
-	if( m_SncVSTplug == NULL )
+	if( m_vstSyncData == NULL )
 	{
 		fprintf(stderr, "RemoteVstPlugin.cpp: "
 			"Failed to initialize shared memory for VST synchronization.\n"
 			" (VST-host synchronization will be disabled)\n");
-		m_SncVSTplug = (sncVST*) malloc( sizeof( sncVST ) );
-		m_SncVSTplug->isPlayin = true;
-		m_SncVSTplug->timeSigNumer = 4;
-		m_SncVSTplug->timeSigDenom = 4;
-		m_SncVSTplug->ppqPos = 0;
-		m_SncVSTplug->isCycle = false;
-		m_SncVSTplug->hasSHM = false;
-		m_SncVSTplug->m_sampleRate = sampleRate();
+		m_vstSyncData = (VstSyncData*) malloc( sizeof( VstSyncData ) );
+		m_vstSyncData->isPlaying = true;
+		m_vstSyncData->timeSigNumer = 4;
+		m_vstSyncData->timeSigDenom = 4;
+		m_vstSyncData->ppqPos = 0;
+		m_vstSyncData->isCycle = false;
+		m_vstSyncData->hasSHM = false;
+		m_vstSyncData->m_sampleRate = sampleRate();
 	}
 
 	m_in = ( in* ) new char[ sizeof( in ) ];
@@ -419,21 +418,6 @@ RemoteVstPlugin::RemoteVstPlugin( key_t _shm_in, key_t _shm_out ) :
 
 RemoteVstPlugin::~RemoteVstPlugin()
 {
-#ifndef USE_QT_SHMEM
-	// detach shared memory segment
-	if( shmdt( m_SncVSTplug ) == -1)
-	{
-		if( __plugin->m_SncVSTplug->hasSHM )
-		{
-			perror( "~RemoteVstPlugin::shmdt" );
-		}
-		if( m_SncVSTplug != NULL )
-		{
-			delete m_SncVSTplug;
-			m_SncVSTplug = NULL;
-		}
-	}
-#endif
 	if( m_window != NULL )
 	{
 		pluginDispatch( effEditClose );
@@ -442,6 +426,23 @@ RemoteVstPlugin::~RemoteVstPlugin()
 #endif
 		m_window = NULL;
 	}
+	pluginDispatch( effMainsChanged, 0, 0 );
+	pluginDispatch( effClose );
+#ifndef USE_QT_SHMEM
+	// detach shared memory segment
+	if( shmdt( m_vstSyncData ) == -1)
+	{
+		if( __plugin->m_vstSyncData->hasSHM )
+		{
+			perror( "~RemoteVstPlugin::shmdt" );
+		}
+		if( m_vstSyncData != NULL )
+		{
+			delete m_vstSyncData;
+			m_vstSyncData = NULL;
+		}
+	}
+#endif
 
 	if( m_libInst != NULL )
 	{
@@ -574,7 +575,7 @@ void RemoteVstPlugin::init( const std::string & _plugin_file )
 	updateInOutCount();
 
 	// some plugins have to set samplerate during init
-	if( m_SncVSTplug->hasSHM )
+	if( m_vstSyncData->hasSHM )
 	{
 		updateSampleRate();
 	}
@@ -689,7 +690,7 @@ void RemoteVstPlugin::initEditor()
 	UpdateWindow( m_window );
 
 #ifdef LMMS_BUILD_LINUX
-	m_windowID = (Sint32) GetProp( m_window, "__wine_x11_whole_window" );
+	m_windowID = (intptr_t) GetProp( m_window, "__wine_x11_whole_window" );
 #endif
 }
 
@@ -739,8 +740,6 @@ bool RemoteVstPlugin::load( const std::string & _plugin_file )
 		return false;
 	}
 
-	m_plugin->user = this;
-
 	if( m_plugin->magic != kEffectMagic )
 	{
 		debugMessage( "File is not a VST plugin\n" );
@@ -774,16 +773,15 @@ void RemoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 		// dispatcher-call, so we create static copies of the
 		// data and post them
 #define MIDI_EVENT_BUFFER_COUNT		1024
-		static char event_buf[sizeof( VstMidiEvent * ) *
-						MIDI_EVENT_BUFFER_COUNT +
-							sizeof( VstEvents )];
+		static char eventsBuffer[sizeof( VstEvents ) + sizeof( VstMidiEvent * ) * MIDI_EVENT_BUFFER_COUNT];
 		static VstMidiEvent vme[MIDI_EVENT_BUFFER_COUNT];
-		VstEvents * events = (VstEvents *) event_buf;
+
+		VstEvents* events = (VstEvents *) eventsBuffer;
 		events->reserved = 0;
 		events->numEvents = m_midiEvents.size();
+
 		int idx = 0;
-		for( VstMidiEventList::iterator it = m_midiEvents.begin();
-					it != m_midiEvents.end(); ++it, ++idx )
+		for( VstMidiEventList::iterator it = m_midiEvents.begin(); it != m_midiEvents.end(); ++it, ++idx )
 		{
 			memcpy( &vme[idx], &*it, sizeof( VstMidiEvent ) );
 			events->events[idx] = (VstEvent *) &vme[idx];
@@ -831,36 +829,37 @@ void RemoteVstPlugin::process( const sampleFrame * _in, sampleFrame * _out )
 
 
 
-void RemoteVstPlugin::processMidiEvent( const midiEvent & _event,
-							const f_cnt_t _offset )
+void RemoteVstPlugin::processMidiEvent( const MidiEvent& event, const f_cnt_t offset )
 {
-	VstMidiEvent event;
+	VstMidiEvent vme;
 
-	event.type = kVstMidiType;
-	event.byteSize = 24;
-	event.deltaFrames = _offset;
-	event.flags = 0;
-	event.detune = 0;
-	event.noteLength = 0;
-	event.noteOffset = 0;
-	event.noteOffVelocity = 0;
-	event.reserved1 = 0;
-	event.reserved2 = 0;
-	event.midiData[0] = _event.m_type + _event.m_channel;
-	switch( _event.m_type )
+	vme.type = kVstMidiType;
+	vme.byteSize = 24;
+	vme.deltaFrames = offset;
+	vme.flags = 0;
+	vme.detune = 0;
+	vme.noteLength = 0;
+	vme.noteOffset = 0;
+	vme.noteOffVelocity = 0;
+	vme.reserved1 = 0;
+	vme.reserved2 = 0;
+	vme.midiData[0] = event.type() + event.channel();
+
+	switch( event.type() )
 	{
 		case MidiPitchBend:
-			event.midiData[1] = _event.m_data.m_param[0] & 0x7f;
-			event.midiData[2] = _event.m_data.m_param[0] >> 7;
+			vme.midiData[1] = event.pitchBend() & 0x7f;
+			vme.midiData[2] = event.pitchBend() >> 7;
 			break;
 		// TODO: handle more special cases
 		default:
-			event.midiData[1] = _event.key();
-			event.midiData[2] = _event.velocity();
+			vme.midiData[1] = event.key();
+			vme.midiData[2] = event.velocity();
 			break;
 	}
-	event.midiData[3] = 0;
-	m_midiEvents.push_back( event );
+	vme.midiData[3] = 0;
+
+	m_midiEvents.push_back( vme );
 }
 
 
@@ -1445,58 +1444,58 @@ intptr_t RemoteVstPlugin::hostCallback( AEffect * _effect, int32_t _opcode,
 			// items may require extensive conversions
 
 			// Shared memory was initialised? - see song.cpp
-			//assert( __plugin->m_SncVSTplug != NULL );
+			//assert( __plugin->m_vstSyncData != NULL );
 
 			memset( &_timeInfo, 0, sizeof( _timeInfo ) );
 			_timeInfo.samplePos = __plugin->m_currentSamplePos;
-			_timeInfo.sampleRate = __plugin->m_SncVSTplug->hasSHM ?
-							__plugin->m_SncVSTplug->m_sampleRate :
+			_timeInfo.sampleRate = __plugin->m_vstSyncData->hasSHM ?
+							__plugin->m_vstSyncData->m_sampleRate :
 							__plugin->sampleRate();
 			_timeInfo.flags = 0;
-			_timeInfo.tempo = __plugin->m_SncVSTplug->hasSHM ?
-							__plugin->m_SncVSTplug->m_bpm :
+			_timeInfo.tempo = __plugin->m_vstSyncData->hasSHM ?
+							__plugin->m_vstSyncData->m_bpm :
 							__plugin->m_bpm;
-			_timeInfo.timeSigNumerator = __plugin->m_SncVSTplug->timeSigNumer;
-			_timeInfo.timeSigDenominator = __plugin->m_SncVSTplug->timeSigDenom;
+			_timeInfo.timeSigNumerator = __plugin->m_vstSyncData->timeSigNumer;
+			_timeInfo.timeSigDenominator = __plugin->m_vstSyncData->timeSigDenom;
 			_timeInfo.flags |= kVstTempoValid;
 			_timeInfo.flags |= kVstTimeSigValid;
 
-			if( __plugin->m_SncVSTplug->isCycle )
+			if( __plugin->m_vstSyncData->isCycle )
 			{
-				_timeInfo.cycleStartPos = __plugin->m_SncVSTplug->cycleStart;
-				_timeInfo.cycleEndPos = __plugin->m_SncVSTplug->cycleEnd;
+				_timeInfo.cycleStartPos = __plugin->m_vstSyncData->cycleStart;
+				_timeInfo.cycleEndPos = __plugin->m_vstSyncData->cycleEnd;
 				_timeInfo.flags |= kVstCyclePosValid;
 				_timeInfo.flags |= kVstTransportCycleActive;
 			}
 
-			if( __plugin->m_SncVSTplug->ppqPos != 
+			if( __plugin->m_vstSyncData->ppqPos != 
 							__plugin->m_in->m_Timestamp )
 			{
-				_timeInfo.ppqPos = __plugin->m_SncVSTplug->ppqPos;
+				_timeInfo.ppqPos = __plugin->m_vstSyncData->ppqPos;
 				_timeInfo.flags |= kVstTransportChanged;
-				__plugin->m_in->lastppqPos = __plugin->m_SncVSTplug->ppqPos;
-				__plugin->m_in->m_Timestamp = __plugin->m_SncVSTplug->ppqPos;
+				__plugin->m_in->lastppqPos = __plugin->m_vstSyncData->ppqPos;
+				__plugin->m_in->m_Timestamp = __plugin->m_vstSyncData->ppqPos;
 			}
-			else if( __plugin->m_SncVSTplug->isPlayin )
+			else if( __plugin->m_vstSyncData->isPlaying )
 			{
 				__plugin->m_in->lastppqPos += (
-							__plugin->m_SncVSTplug->hasSHM ?
-							__plugin->m_SncVSTplug->m_bpm :
+							__plugin->m_vstSyncData->hasSHM ?
+							__plugin->m_vstSyncData->m_bpm :
 							__plugin->m_bpm ) / (float)10340;
 				_timeInfo.ppqPos = __plugin->m_in->lastppqPos;
 			}
-//			_timeInfo.ppqPos = __plugin->m_SncVSTplug->ppqPos;
+//			_timeInfo.ppqPos = __plugin->m_vstSyncData->ppqPos;
 			_timeInfo.flags |= kVstPpqPosValid;
 
-			if( __plugin->m_SncVSTplug->isPlayin )
+			if( __plugin->m_vstSyncData->isPlaying )
 			{
 				_timeInfo.flags |= kVstTransportPlaying;
 			}
 			_timeInfo.barStartPos = ( (int) ( _timeInfo.ppqPos / 
-				( 4 *__plugin->m_SncVSTplug->timeSigNumer
-				/ (float) __plugin->m_SncVSTplug->timeSigDenom ) ) ) *
-				( 4 * __plugin->m_SncVSTplug->timeSigNumer
-				/ (float) __plugin->m_SncVSTplug->timeSigDenom );
+				( 4 *__plugin->m_vstSyncData->timeSigNumer
+				/ (float) __plugin->m_vstSyncData->timeSigDenom ) ) ) *
+				( 4 * __plugin->m_vstSyncData->timeSigNumer
+				/ (float) __plugin->m_vstSyncData->timeSigDenom );
 
 			_timeInfo.flags |= kVstBarsValid;
 
@@ -1861,10 +1860,12 @@ int main( int _argc, char * * _argv )
 	}
 
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 	// (non-portable) initialization of statically linked pthread library
 	pthread_win32_process_attach_np();
 	pthread_win32_thread_attach_np();
 #endif
+#endif
 
 #ifdef LMMS_BUILD_LINUX
 #ifdef LMMS_HAVE_SCHED_H
@@ -1898,8 +1899,10 @@ int main( int _argc, char * * _argv )
 
 
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 	pthread_win32_thread_detach_np();
 	pthread_win32_process_detach_np();
+#endif
 #endif
 
 	return 0;
