@@ -1,7 +1,7 @@
 /*
  * RemoteZynAddSubFx.cpp - ZynAddSubFx-embedding plugin
  *
- * Copyright (c) 2008-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2008-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -119,6 +119,10 @@ public:
 				LocalZynAddSubFx::setLmmsWorkingDir( _m.getString() );
 				break;
 
+			case IdZasfSetPitchWheelBendRange:
+				LocalZynAddSubFx::setPitchWheelBendRange( _m.getInt() );
+				break;
+
 			default:
 				return RemotePluginClient::processMessage( _m );
 		}
@@ -126,10 +130,9 @@ public:
 	}
 
 	// all functions are called while m_master->mutex is held
-	virtual void processMidiEvent( const midiEvent & _e,
-									const f_cnt_t /* _offset */ )
+	virtual void processMidiEvent( const MidiEvent& event, const f_cnt_t /* _offset */ )
 	{
-		LocalZynAddSubFx::processMidiEvent( _e );
+		LocalZynAddSubFx::processMidiEvent( event );
 	}
 
 
@@ -260,10 +263,12 @@ int main( int _argc, char * * _argv )
 	}
 
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 	// (non-portable) initialization of statically linked pthread library
 	pthread_win32_process_attach_np();
 	pthread_win32_thread_attach_np();
 #endif
+#endif
 
 
 	RemoteZynAddSubFx * remoteZASF =
@@ -275,8 +280,10 @@ int main( int _argc, char * * _argv )
 
 
 #ifdef LMMS_BUILD_WIN32
+#ifndef __WINPTHREADS_VERSION
 	pthread_win32_thread_detach_np();
 	pthread_win32_process_detach_np();
+#endif
 #endif
 
 	return 0;
