@@ -2,7 +2,7 @@
  * track.cpp - implementation of classes concerning tracks -> necessary for
  *             all track-like objects (beat/bassline, sample-track...)
  *
- * Copyright (c) 2004-2012 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -59,26 +59,26 @@
 #include "gui_templates.h"
 #include "InstrumentTrack.h"
 #include "MainWindow.h"
-#include "mmp.h"
+#include "DataFile.h"
 #include "pixmap_button.h"
 #include "ProjectJournal.h"
-#include "sample_track.h"
+#include "SampleTrack.h"
 #include "song.h"
 #include "string_pair_drag.h"
 #include "templates.h"
 #include "text_float.h"
 #include "tooltip.h"
-#include "track_container.h"
+#include "TrackContainer.h"
 
 
 /*! The width of the resize grip in pixels
  */
-const Sint16 RESIZE_GRIP_WIDTH = 4;
+const int RESIZE_GRIP_WIDTH = 4;
 
 /*! The size of the track buttons in pixels
  */
-const Uint16 TRACK_OP_BTN_WIDTH = 20;
-const Uint16 TRACK_OP_BTN_HEIGHT = 14;
+const int TRACK_OP_BTN_WIDTH = 20;
+const int TRACK_OP_BTN_HEIGHT = 14;
 
 
 /*! A pointer for that text bubble used when moving segments, etc.
@@ -145,7 +145,7 @@ trackContentObject::~trackContentObject()
  *
  * \param _pos The new position of the track content object.
  */
-void trackContentObject::movePosition( const midiTime & _pos )
+void trackContentObject::movePosition( const MidiTime & _pos )
 {
 	if( m_startPosition != _pos )
 	{
@@ -166,7 +166,7 @@ void trackContentObject::movePosition( const midiTime & _pos )
  *
  * \param _length The new length of the track content object.
  */
-void trackContentObject::changeLength( const midiTime & _length )
+void trackContentObject::changeLength( const MidiTime & _length )
 {
 	if( m_length != _length )
 	{
@@ -243,7 +243,7 @@ void trackContentObject::paste()
 {
 	if( Clipboard::getContent( nodeName() ) != NULL )
 	{
-		const midiTime pos = startPosition();
+		const MidiTime pos = startPosition();
 		restoreState( *( Clipboard::getContent( nodeName() ) ) );
 		movePosition( pos );
 	}
@@ -336,7 +336,7 @@ trackContentObjectView::~trackContentObjectView()
 	// op-buttons of our track-widgets could become focus and when the user
 	// presses space for playing song, just one of these buttons is pressed
 	// which results in unwanted effects
-	m_trackView->getTrackContainerView()->setFocus();
+	m_trackView->trackContainerView()->setFocus();
 }
 
 
@@ -352,7 +352,7 @@ trackContentObjectView::~trackContentObjectView()
  */
 bool trackContentObjectView::fixedTCOs()
 {
-	return m_trackView->getTrackContainerView()->fixedTCOs();
+	return m_trackView->trackContainerView()->fixedTCOs();
 }
 
 
@@ -422,10 +422,10 @@ void trackContentObjectView::updateLength()
 	{
 		setFixedWidth(
 		static_cast<int>( m_tco->length() * pixelsPerTact() /
-					midiTime::ticksPerTact() ) +
-						TCO_BORDER_WIDTH * 2-1 );
+					MidiTime::ticksPerTact() ) + 1 /*+
+						TCO_BORDER_WIDTH * 2-1*/ );
 	}
-	m_trackView->getTrackContainerView()->update();
+	m_trackView->trackContainerView()->update();
 }
 
 
@@ -443,7 +443,7 @@ void trackContentObjectView::updatePosition()
 	m_trackView->getTrackContentWidget()->changePosition();
 	// moving a TCO can result in change of song-length etc.,
 	// therefore we update the track-container
-	m_trackView->getTrackContainerView()->update();
+	m_trackView->trackContainerView()->update();
 }
 
 
@@ -468,7 +468,7 @@ void trackContentObjectView::dragEnterEvent( QDragEnterEvent * _dee )
 /*! \brief Handle something being dropped on this trackContentObjectView.
  *
  *  When something has been dropped on this trackContentObjectView, and
- *  it's a track content object, then use an instance of our mmp reader
+ *  it's a track content object, then use an instance of our dataFile reader
  *  to take the xml of the track content object and turn it into something
  *  we can write over our current state.
  *
@@ -481,12 +481,12 @@ void trackContentObjectView::dropEvent( QDropEvent * _de )
 	if( type == ( "tco_" + QString::number( m_tco->getTrack()->type() ) ) )
 	{
 		// value contains our XML-data so simply create a
-		// multimediaProject which does the rest for us...
-		multimediaProject mmp( value.toUtf8() );
+		// DataFile which does the rest for us...
+		DataFile dataFile( value.toUtf8() );
 		// at least save position before getting to moved to somewhere
 		// the user doesn't expect...
-		midiTime pos = m_tco->startPosition();
-		m_tco->restoreState( mmp.content().firstChild().toElement() );
+		MidiTime pos = m_tco->startPosition();
+		m_tco->restoreState( dataFile.content().firstChild().toElement() );
  		m_tco->movePosition( pos );
 		AutomationPattern::resolveAllIDs();
 		_de->accept();
@@ -532,11 +532,11 @@ void trackContentObjectView::leaveEvent( QEvent * _e )
  */
 void trackContentObjectView::mousePressEvent( QMouseEvent * _me )
 {
-	if( m_trackView->getTrackContainerView()->allowRubberband() == true &&
+	if( m_trackView->trackContainerView()->allowRubberband() == true &&
 					_me->button() == Qt::LeftButton )
 	{
 		// if rubberband is active, we can be selected
-		if( !m_trackView->getTrackContainerView()->rubberBandActive() )
+		if( !m_trackView->trackContainerView()->rubberBandActive() )
 		{
 			if( _me->modifiers() & Qt::ControlModifier )
 			{
@@ -563,15 +563,15 @@ void trackContentObjectView::mousePressEvent( QMouseEvent * _me )
 			_me->modifiers() & Qt::ControlModifier )
 	{
 		// start drag-action
-		multimediaProject mmp( multimediaProject::DragNDropData );
-		m_tco->saveState( mmp, mmp.content() );
+		DataFile dataFile( DataFile::DragNDropData );
+		m_tco->saveState( dataFile, dataFile.content() );
 		QPixmap thumbnail = QPixmap::grabWidget( this ).scaled(
 						128, 128,
 						Qt::KeepAspectRatio,
 						Qt::SmoothTransformation );
 		new stringPairDrag( QString( "tco_%1" ).arg(
 						m_tco->getTrack()->type() ),
-					mmp.toString(), thumbnail, this );
+					dataFile.toString(), thumbnail, this );
 	}
 	else if( _me->button() == Qt::LeftButton &&
 		/*	engine::mainWindow()->isShiftPressed() == false &&*/
@@ -650,13 +650,13 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 		m_hint = NULL;
 	}
 
-	const float ppt = m_trackView->getTrackContainerView()->pixelsPerTact();
+	const float ppt = m_trackView->trackContainerView()->pixelsPerTact();
 	if( m_action == Move )
 	{
 		const int x = mapToParent( _me->pos() ).x() - m_initialMouseX;
-		midiTime t = qMax( 0, (int)
-			m_trackView->getTrackContainerView()->currentPosition()+
-				static_cast<int>( x * midiTime::ticksPerTact() /
+		MidiTime t = qMax( 0, (int)
+			m_trackView->trackContainerView()->currentPosition()+
+				static_cast<int>( x * MidiTime::ticksPerTact() /
 									ppt ) );
 		if( ! ( _me->modifiers() & Qt::ControlModifier )
 		   && _me->button() == Qt::NoButton )
@@ -668,7 +668,7 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 		s_textFloat->setText( QString( "%1:%2" ).
 				arg( m_tco->startPosition().getTact() + 1 ).
 				arg( m_tco->startPosition().getTicks() %
-						midiTime::ticksPerTact() ) );
+						MidiTime::ticksPerTact() ) );
 		s_textFloat->moveGlobal( this, QPoint( width() + 2,
 		                                        height() + 2 ) );
 	}
@@ -676,9 +676,9 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 	{
 		const int dx = _me->x() - m_initialMouseX;
 		QVector<selectableObject *> so =
-			m_trackView->getTrackContainerView()->selectedObjects();
+			m_trackView->trackContainerView()->selectedObjects();
 		QVector<trackContentObject *> tcos;
-		midiTime smallest_pos, t;
+		MidiTime smallest_pos, t;
 		// find out smallest position of all selected objects for not
 		// moving an object before zero
 		for( QVector<selectableObject *>::iterator it = so.begin();
@@ -695,13 +695,13 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 			smallest_pos = qMin<int>( smallest_pos,
 					(int)tco->startPosition() +
 				static_cast<int>( dx *
-					midiTime::ticksPerTact() / ppt ) );
+					MidiTime::ticksPerTact() / ppt ) );
 		}
 		for( QVector<trackContentObject *>::iterator it = tcos.begin();
 							it != tcos.end(); ++it )
 		{
 			t = ( *it )->startPosition() +
-				static_cast<int>( dx *midiTime::ticksPerTact() /
+				static_cast<int>( dx *MidiTime::ticksPerTact() /
 					 ppt )-smallest_pos;
 			if( ! ( _me->modifiers() & Qt::AltModifier )
 					   && _me->button() == Qt::NoButton )
@@ -713,25 +713,22 @@ void trackContentObjectView::mouseMoveEvent( QMouseEvent * _me )
 	}
 	else if( m_action == Resize )
 	{
-		midiTime t = qMax( midiTime::ticksPerTact(),
-				static_cast<int>( _me->x() *
-					midiTime::ticksPerTact() / ppt ) );
-		if( ! ( _me->modifiers() & Qt::ControlModifier )
-		   && _me->button() == Qt::NoButton )
+		MidiTime t = qMax( MidiTime::ticksPerTact() / 16, static_cast<int>( _me->x() * MidiTime::ticksPerTact() / ppt ) );
+		if( ! ( _me->modifiers() & Qt::ControlModifier ) && _me->button() == Qt::NoButton )
 		{
-			t = t.toNearestTact();
+			t = qMax<int>( MidiTime::ticksPerTact(), t.toNearestTact() );
 		}
 		m_tco->changeLength( t );
 		s_textFloat->setText( tr( "%1:%2 (%3:%4 to %5:%6)" ).
 				arg( m_tco->length().getTact() ).
 				arg( m_tco->length().getTicks() %
-						midiTime::ticksPerTact() ).
+						MidiTime::ticksPerTact() ).
 				arg( m_tco->startPosition().getTact() + 1 ).
 				arg( m_tco->startPosition().getTicks() %
-						midiTime::ticksPerTact() ).
+						MidiTime::ticksPerTact() ).
 				arg( m_tco->endPosition().getTact() + 1 ).
 				arg( m_tco->endPosition().getTicks() %
-						midiTime::ticksPerTact() ) );
+						MidiTime::ticksPerTact() ) );
 		s_textFloat->moveGlobal( this, QPoint( width() + 2,
 					height() + 2) );
 	}
@@ -830,7 +827,7 @@ void trackContentObjectView::contextMenuEvent( QContextMenuEvent * _cme )
  */
 float trackContentObjectView::pixelsPerTact()
 {
-	return m_trackView->getTrackContainerView()->pixelsPerTact();
+	return m_trackView->trackContainerView()->pixelsPerTact();
 }
 
 
@@ -866,9 +863,9 @@ trackContentWidget::trackContentWidget( trackView * _parent ) :
 {
 	setAcceptDrops( true );
 
-	connect( _parent->getTrackContainerView(),
-			SIGNAL( positionChanged( const midiTime & ) ),
-			this, SLOT( changePosition( const midiTime & ) ) );
+	connect( _parent->trackContainerView(),
+			SIGNAL( positionChanged( const MidiTime & ) ),
+			this, SLOT( changePosition( const MidiTime & ) ) );
 
 	updateBackground();
 }
@@ -890,51 +887,48 @@ trackContentWidget::~trackContentWidget()
 void trackContentWidget::updateBackground()
 {
 	const int tactsPerBar = 4;
-	const trackContainerView * tcv = m_trackView->getTrackContainerView();
+	const TrackContainerView * tcv = m_trackView->trackContainerView();
 
 	// Assume even-pixels-per-tact. Makes sense, should be like this anyways
 	int ppt = static_cast<int>( tcv->pixelsPerTact() );
 
-    int w = ppt * tactsPerBar;
-    int h = height();
-    m_background = QPixmap( w * 2, height() );
-    QPainter pmp( &m_background );
+	int w = ppt * tactsPerBar;
+	int h = height();
+	m_background = QPixmap( w * 2, height() );
+	QPainter pmp( &m_background );
 
-    QLinearGradient grad( 0, 1, 0, h-2 );
-    pmp.fillRect( 0, 0, 1, h, QColor( 96, 96, 96 ) );
-    pmp.fillRect( 1, 0, w+1, h, QColor( 128, 128, 128 ) );
-    grad.setColorAt( 0.0, QColor( 64, 64, 64 ) );
-    grad.setColorAt( 0.3, QColor( 128, 128, 128 ) );
-    grad.setColorAt( 0.5, QColor( 128, 128, 128 ) );
-    grad.setColorAt( 0.95, QColor( 160, 160, 160 ) );
-    pmp.fillRect( 0, 1, w, h-2, grad );
+	QLinearGradient grad( 0,0, 0, h );
+	grad.setColorAt( 0.0, QColor( 50, 50, 50 ) );
+	grad.setColorAt( 0.33, QColor( 20, 20, 20 ) );
+	grad.setColorAt( 1.0, QColor( 15, 15, 15 ) );
+	pmp.fillRect( 0, 0, w, h, grad );
 
-    QLinearGradient grad2( 0,1, 0, h-2 );
-    pmp.fillRect( w+1, 0, w , h, QColor( 96, 96, 96 ) );
-    grad2.setColorAt( 0.0, QColor( 48, 48, 48 ) );
-    grad2.setColorAt( 0.3, QColor( 96, 96, 96 ) );
-    grad2.setColorAt( 0.5, QColor( 96, 96, 96 ) );
-    grad2.setColorAt( 0.95, QColor( 120, 120, 120 ) );
-    pmp.fillRect( w, 1, w , h-2, grad2 );
+	QLinearGradient grad2( 0,0, 0, h );
+	grad2.setColorAt( 0.0, QColor( 50, 50, 50 ) );
+	grad2.setColorAt( 0.33, QColor( 40, 40, 40 ) );
+	grad2.setColorAt( 1.0, QColor( 30, 30, 30 ) );
+	pmp.fillRect( w, 0, w , h, grad2 );
 
-    // draw vertical lines
-    pmp.setPen( QPen( QColor( 0, 0, 0, 112 ), 1 ) );
-    for( float x = 0.5; x < w * 2; x += ppt )
-    {
-        pmp.drawLine( QLineF( x, 1.0, x, h-2.0 ) );
-    }
-    pmp.drawLine( 0, 1, w*2, 1 );
+	// draw lines
+	pmp.setPen( QPen( QColor( 0, 0, 0, 160 ), 1 ) );
+	// horizontal line
+	pmp.drawLine( 0, 0, w*2, 0 );
 
-    pmp.setPen( QPen( QColor( 255, 255, 255, 32 ), 1 ) );
-    for( float x = 1.5; x < w * 2; x += ppt )
-    {
-        pmp.drawLine( QLineF( x, 1.0, x, h-2.0 ) );
-    }
-    pmp.drawLine( 0, h-2, w*2, h-2 );
+	// vertical lines
+	for( float x = 0; x < w * 2; x += ppt )
+	{
+		pmp.drawLine( QLineF( x, 0.0, x, h ) );
+	}
 
-    pmp.end();
+	pmp.setPen( QPen( QColor( 140, 140, 140, 64 ), 1 ) );
+	for( float x = 1.0; x < w * 2; x += ppt )
+	{
+		pmp.drawLine( QLineF( x, 0.0, x, h ) );
+	}
 
-    // Force redraw
+	pmp.end();
+
+	// Force redraw
 	update();
 }
 
@@ -979,10 +973,10 @@ void trackContentWidget::removeTCOView( trackContentObjectView * _tcov )
 	if( it != m_tcoViews.end() )
 	{
 /*		QMap<QString, QVariant> map;
-		multimediaProject mmp( multimediaProject::JournalData );
-		_tcov->getTrackContentObject()->saveState( mmp, mmp.content() );
+		DataFile dataFile( DataFile::JournalData );
+		_tcov->getTrackContentObject()->saveState( dataFile, dataFile.content() );
 		map["id"] = _tcov->getTrackContentObject()->id();
-		map["state"] = mmp.toString();
+		map["state"] = dataFile.toString();
 		addJournalEntry( JournalEntry( RemoveTrackContentObject,
 								map ) );*/
 
@@ -1017,9 +1011,9 @@ void trackContentWidget::update()
  *
  * \param _new_pos The MIDI time to move to.
  */
-void trackContentWidget::changePosition( const midiTime & _new_pos )
+void trackContentWidget::changePosition( const MidiTime & _new_pos )
 {
-	if( m_trackView->getTrackContainerView() == engine::getBBEditor() )
+	if( m_trackView->trackContainerView() == engine::getBBEditor() )
 	{
 		const int cur_bb = engine::getBBTrackContainer()->currentBB();
 		setUpdatesEnabled( false );
@@ -1054,15 +1048,15 @@ void trackContentWidget::changePosition( const midiTime & _new_pos )
 		return;
 	}
 
-	midiTime pos = _new_pos;
+	MidiTime pos = _new_pos;
 	if( pos < 0 )
 	{
-		pos = m_trackView->getTrackContainerView()->currentPosition();
+		pos = m_trackView->trackContainerView()->currentPosition();
 	}
 
 	const int begin = pos;
 	const int end = endPosition( pos );
-	const float ppt = m_trackView->getTrackContainerView()->pixelsPerTact();
+	const float ppt = m_trackView->trackContainerView()->pixelsPerTact();
 
 	setUpdatesEnabled( false );
 	for( tcoViewVector::iterator it = m_tcoViews.begin();
@@ -1080,7 +1074,7 @@ void trackContentWidget::changePosition( const midiTime & _new_pos )
 			( ts <= begin && te >= end ) )
 		{
 			tcov->move( static_cast<int>( ( ts - begin ) * ppt /
-						midiTime::ticksPerTact() ),
+						MidiTime::ticksPerTact() ),
 								tcov->y() );
 			if( !tcov->isVisible() )
 			{
@@ -1123,18 +1117,18 @@ void trackContentWidget::dropEvent( QDropEvent * _de )
 	QString type = stringPairDrag::decodeKey( _de );
 	QString value = stringPairDrag::decodeValue( _de );
 	if( type == ( "tco_" + QString::number( getTrack()->type() ) ) &&
-		m_trackView->getTrackContainerView()->fixedTCOs() == false )
+		m_trackView->trackContainerView()->fixedTCOs() == false )
 	{
-		const midiTime pos = getPosition( _de->pos().x()
-							).toNearestTact();
+		const MidiTime pos = getPosition( _de->pos().x()
+                            ).getTact() * MidiTime::ticksPerTact();
 		trackContentObject * tco = getTrack()->createTCO( pos );
 
 		// value contains our XML-data so simply create a
-		// multimediaProject which does the rest for us...
-		multimediaProject mmp( value.toUtf8() );
+		// DataFile which does the rest for us...
+		DataFile dataFile( value.toUtf8() );
 		// at least save position before getting moved to somewhere
 		// the user doesn't expect...
-		tco->restoreState( mmp.content().firstChild().toElement() );
+		tco->restoreState( dataFile.content().firstChild().toElement() );
 		tco->movePosition( pos );
 
 		AutomationPattern::resolveAllIDs();
@@ -1154,7 +1148,7 @@ void trackContentWidget::dropEvent( QDropEvent * _de )
  */
 void trackContentWidget::mousePressEvent( QMouseEvent * _me )
 {
-	if( m_trackView->getTrackContainerView()->allowRubberband() == true )
+	if( m_trackView->trackContainerView()->allowRubberband() == true )
 	{
 		QWidget::mousePressEvent( _me );
 	}
@@ -1163,10 +1157,10 @@ void trackContentWidget::mousePressEvent( QMouseEvent * _me )
 		QWidget::mousePressEvent( _me );
 	}
 	else if( _me->button() == Qt::LeftButton &&
-			!m_trackView->getTrackContainerView()->fixedTCOs() )
+			!m_trackView->trackContainerView()->fixedTCOs() )
 	{
-		const midiTime pos = getPosition( _me->x() ).getTact() *
-						midiTime::ticksPerTact();
+		const MidiTime pos = getPosition( _me->x() ).getTact() *
+						MidiTime::ticksPerTact();
 		trackContentObject * tco = getTrack()->createTCO( pos );
 
 		tco->saveJournallingState( false );
@@ -1186,11 +1180,11 @@ void trackContentWidget::mousePressEvent( QMouseEvent * _me )
 void trackContentWidget::paintEvent( QPaintEvent * _pe )
 {
 	// Assume even-pixels-per-tact. Makes sense, should be like this anyways
-	const trackContainerView * tcv = m_trackView->getTrackContainerView();
+	const TrackContainerView * tcv = m_trackView->trackContainerView();
 	int ppt = static_cast<int>( tcv->pixelsPerTact() );
 	QPainter p( this );
 	// Don't draw background on BB-Editor
-	if( m_trackView->getTrackContainerView() != engine::getBBEditor() )
+	if( m_trackView->trackContainerView() != engine::getBBEditor() )
 	{
 		p.drawTiledPixmap( rect(), m_background, QPoint(
 				tcv->currentPosition().getTact() * ppt, 0 ) );
@@ -1206,7 +1200,9 @@ void trackContentWidget::paintEvent( QPaintEvent * _pe )
  */
 void trackContentWidget::resizeEvent( QResizeEvent * resizeEvent )
 {
+	// Update backgroud
 	updateBackground();
+	// Force redraw
 	QWidget::resizeEvent( resizeEvent );
 }
 
@@ -1228,9 +1224,9 @@ void trackContentWidget::undoStep( JournalEntry & _je )
 			trackContentObject * tco =
 				dynamic_cast<trackContentObject *>(
 			engine::projectJournal()->journallingObject( map["id"].toInt() ) );
-			multimediaProject mmp( multimediaProject::JournalData );
-			tco->saveState( mmp, mmp.content() );
-			map["state"] = mmp.toString();
+			DataFile dataFile( DataFile::JournalData );
+			tco->saveState( dataFile, dataFile.content() );
+			map["state"] = dataFile.toString();
 			_je.data() = map;
 			tco->deleteLater();
 			break;
@@ -1238,11 +1234,11 @@ void trackContentWidget::undoStep( JournalEntry & _je )
 
 		case RemoveTrackContentObject:
 		{
-			trackContentObject * tco = getTrack()->createTCO( midiTime( 0 ) );
-			multimediaProject mmp(
+			trackContentObject * tco = getTrack()->createTCO( MidiTime( 0 ) );
+			DataFile dataFile(
 				_je.data().toMap()["state"].
 					toString().toUtf8() );
-			tco->restoreState( mmp.content().firstChild().toElement() );
+			tco->restoreState( dataFile.content().firstChild().toElement() );
 			break;
 		}
 	}
@@ -1293,13 +1289,13 @@ track * trackContentWidget::getTrack()
  *
  * \param _mouse_x the mouse's current X position in pixels.
  */
-midiTime trackContentWidget::getPosition( int _mouse_x )
+MidiTime trackContentWidget::getPosition( int _mouse_x )
 {
-	return midiTime( m_trackView->getTrackContainerView()->
+	return MidiTime( m_trackView->trackContainerView()->
 					currentPosition() + _mouse_x *
-						midiTime::ticksPerTact() /
+						MidiTime::ticksPerTact() /
 			static_cast<int>( m_trackView->
-				getTrackContainerView()->pixelsPerTact() ) );
+				trackContainerView()->pixelsPerTact() ) );
 }
 
 
@@ -1308,11 +1304,11 @@ midiTime trackContentWidget::getPosition( int _mouse_x )
  *
  * \param _pos_start the starting position of the Widget (from getPosition())
  */
-midiTime trackContentWidget::endPosition( const midiTime & _pos_start )
+MidiTime trackContentWidget::endPosition( const MidiTime & _pos_start )
 {
-	const float ppt = m_trackView->getTrackContainerView()->pixelsPerTact();
+	const float ppt = m_trackView->trackContainerView()->pixelsPerTact();
 	const int w = width();
-	return _pos_start + static_cast<int>( w * midiTime::ticksPerTact() / ppt );
+	return _pos_start + static_cast<int>( w * MidiTime::ticksPerTact() / ppt );
 }
 
 
@@ -1391,7 +1387,7 @@ trackOperationsWidget::trackOperationsWidget( trackView * _parent ) :
 	toolTip::add( m_soloBtn, tr( "Solo" ) );
 
 	connect( this, SIGNAL( trackRemovalScheduled( trackView * ) ),
-			m_trackView->getTrackContainerView(),
+			m_trackView->trackContainerView(),
 				SLOT( deleteTrackView( trackView * ) ),
 							Qt::QueuedConnection );
 }
@@ -1425,11 +1421,11 @@ void trackOperationsWidget::mousePressEvent( QMouseEvent * _me )
 		_me->modifiers() & Qt::ControlModifier &&
 			m_trackView->getTrack()->type() != track::BBTrack )
 	{
-		multimediaProject mmp( multimediaProject::DragNDropData );
-		m_trackView->getTrack()->saveState( mmp, mmp.content() );
+		DataFile dataFile( DataFile::DragNDropData );
+		m_trackView->getTrack()->saveState( dataFile, dataFile.content() );
 		new stringPairDrag( QString( "track_%1" ).arg(
 					m_trackView->getTrack()->type() ),
-			mmp.toString(), QPixmap::grabWidget(
+			dataFile.toString(), QPixmap::grabWidget(
 				m_trackView->getTrackSettingsWidget() ),
 									this );
 	}
@@ -1482,9 +1478,9 @@ void trackOperationsWidget::paintEvent( QPaintEvent * _pe )
  */
 void trackOperationsWidget::cloneTrack()
 {
-	engine::getMixer()->lock();
+	engine::mixer()->lock();
 	m_trackView->getTrack()->clone();
-	engine::getMixer()->unlock();
+	engine::mixer()->unlock();
 }
 
 
@@ -1543,7 +1539,7 @@ void trackOperationsWidget::updateMenu()
  *
  * \todo check the definitions of all the properties - are they OK?
  */
-track::track( TrackTypes _type, trackContainer * _tc ) :
+track::track( TrackTypes _type, TrackContainer * _tc ) :
 	Model( _tc ),                   /*!< The track Model */
 	m_trackContainer( _tc ),        /*!< The track container object */
 	m_type( _type ),                /*!< The track type */
@@ -1592,7 +1588,7 @@ track::~track()
  *  \param _tt The type of track to create
  *  \param _tc The track container to attach to
  */
-track * track::create( TrackTypes _tt, trackContainer * _tc )
+track * track::create( TrackTypes _tt, TrackContainer * _tc )
 {
 	track * t = NULL;
 
@@ -1600,7 +1596,7 @@ track * track::create( TrackTypes _tt, trackContainer * _tc )
 	{
 		case InstrumentTrack: t = new ::InstrumentTrack( _tc ); break;
 		case BBTrack: t = new bbTrack( _tc ); break;
-		case SampleTrack: t = new sampleTrack( _tc ); break;
+		case SampleTrack: t = new ::SampleTrack( _tc ); break;
 //		case EVENT_TRACK:
 //		case VIDEO_TRACK:
 		case AutomationTrack: t = new ::AutomationTrack( _tc ); break;
@@ -1617,12 +1613,12 @@ track * track::create( TrackTypes _tt, trackContainer * _tc )
 
 
 
-/*! \brief Create a track inside trackContainer from track type in a QDomElement and restore state from XML
+/*! \brief Create a track inside TrackContainer from track type in a QDomElement and restore state from XML
  *
  *  \param _this The QDomElement containing the type of track to create
  *  \param _tc The track container to attach to
  */
-track * track::create( const QDomElement & _this, trackContainer * _tc )
+track * track::create( const QDomElement & _this, TrackContainer * _tc )
 {
 	track * t = create(
 		static_cast<TrackTypes>( _this.attribute( "type" ).toInt() ),
@@ -1655,7 +1651,7 @@ void track::clone()
 
 /*! \brief Save this track's settings to file
  *
- *  We save the track type and its muted state, then append the track-
+ *  We save the track type and its muted state and solo state, then append the track-
  *  specific settings.  Then we iterate through the trackContentObjects
  *  and save all their states in turn.
  *
@@ -1673,6 +1669,7 @@ void track::saveSettings( QDomDocument & _doc, QDomElement & _this )
 	_this.setAttribute( "type", type() );
 	_this.setAttribute( "name", name() );
 	_this.setAttribute( "muted", isMuted() );
+	_this.setAttribute( "solo", isSolo() );
 	if( m_height >= MINIMAL_TRACK_HEIGHT )
 	{
 		_this.setAttribute( "height", m_height );
@@ -1703,7 +1700,7 @@ void track::saveSettings( QDomDocument & _doc, QDomElement & _this )
 
 /*! \brief Load the settings from a file
  *
- *  We load the track's type and muted state, then clear out our
+ *  We load the track's type and muted state and solo state, then clear out our
  *  current trackContentObject.
  *
  *  Then we step through the QDomElement's children and load the
@@ -1725,6 +1722,7 @@ void track::loadSettings( const QDomElement & _this )
 			_this.firstChild().toElement().attribute( "name" ) );
 
 	setMuted( _this.attribute( "muted" ).toInt() );
+	setSolo( _this.attribute( "solo" ).toInt() );
 
 	if( m_simpleSerializingMode )
 	{
@@ -1761,7 +1759,7 @@ void track::loadSettings( const QDomElement & _this )
 			!node.toElement().attribute( "metadata" ).toInt() )
 			{
 				trackContentObject * tco = createTCO(
-								midiTime( 0 ) );
+								MidiTime( 0 ) );
 				tco->restoreState( node.toElement() );
 				saveJournallingState( false );
 				restoreJournallingState();
@@ -1851,8 +1849,8 @@ trackContentObject * track::getTCO( int _tco_num )
 	}
 	printf( "called track::getTCO( %d ), "
 			"but TCO %d doesn't exist\n", _tco_num, _tco_num );
-	return createTCO( _tco_num * midiTime::ticksPerTact() );
-	
+	return createTCO( _tco_num * MidiTime::ticksPerTact() );
+
 }
 
 
@@ -1897,8 +1895,8 @@ int track::getTCONum( trackContentObject * _tco )
  *  \param _start The MIDI start time of the range.
  *  \param _end   The MIDI endi time of the range.
  */
-void track::getTCOsInRange( tcoVector & _tco_v, const midiTime & _start,
-							const midiTime & _end )
+void track::getTCOsInRange( tcoVector & _tco_v, const MidiTime & _start,
+							const MidiTime & _end )
 {
 	for( tcoVector::iterator it_o = m_trackContentObjects.begin();
 				it_o != m_trackContentObjects.end(); ++it_o )
@@ -1947,7 +1945,7 @@ void track::swapPositionOfTCOs( int _tco_num1, int _tco_num2 )
 	qSwap( m_trackContentObjects[_tco_num1],
 					m_trackContentObjects[_tco_num2] );
 
-	const midiTime pos = m_trackContentObjects[_tco_num1]->startPosition();
+	const MidiTime pos = m_trackContentObjects[_tco_num1]->startPosition();
 
 	m_trackContentObjects[_tco_num1]->movePosition(
 			m_trackContentObjects[_tco_num2]->startPosition() );
@@ -1964,7 +1962,7 @@ void track::swapPositionOfTCOs( int _tco_num1, int _tco_num2 )
  *    in ascending order by TCO time, once we hit a TCO that was earlier
  *    than the insert time, we could fall out of the loop early.
  */
-void track::insertTact( const midiTime & _pos )
+void track::insertTact( const MidiTime & _pos )
 {
 	// we'll increase the position of every TCO, positioned behind _pos, by
 	// one tact
@@ -1974,7 +1972,7 @@ void track::insertTact( const midiTime & _pos )
 		if( ( *it )->startPosition() >= _pos )
 		{
 			( *it )->movePosition( (*it)->startPosition() +
-						midiTime::ticksPerTact() );
+						MidiTime::ticksPerTact() );
 		}
 	}
 }
@@ -1986,7 +1984,7 @@ void track::insertTact( const midiTime & _pos )
  *
  *  \param _pos The time at which we want to remove the bar.
  */
-void track::removeTact( const midiTime & _pos )
+void track::removeTact( const MidiTime & _pos )
 {
 	// we'll decrease the position of every TCO, positioned behind _pos, by
 	// one tact
@@ -1996,7 +1994,7 @@ void track::removeTact( const midiTime & _pos )
 		if( ( *it )->startPosition() >= _pos )
 		{
 			( *it )->movePosition( qMax( ( *it )->startPosition() -
-						midiTime::ticksPerTact(), 0 ) );
+						MidiTime::ticksPerTact(), 0 ) );
 		}
 	}
 }
@@ -2024,7 +2022,7 @@ tact_t track::length() const
 		}
 	}
 
-	return last / midiTime::ticksPerTact();
+	return last / MidiTime::ticksPerTact();
 }
 
 
@@ -2037,10 +2035,10 @@ tact_t track::length() const
  */
 void track::toggleSolo()
 {
-	const trackContainer::trackList & tl = m_trackContainer->tracks();
+	const TrackContainer::TrackList & tl = m_trackContainer->tracks();
 
 	bool solo_before = false;
-	for( trackContainer::trackList::const_iterator it = tl.begin();
+	for( TrackContainer::TrackList::const_iterator it = tl.begin();
 							it != tl.end(); ++it )
 	{
 		if( *it != this )
@@ -2054,7 +2052,7 @@ void track::toggleSolo()
 	}
 
 	const bool solo = m_soloModel.value();
-	for( trackContainer::trackList::const_iterator it = tl.begin();
+	for( TrackContainer::TrackList::const_iterator it = tl.begin();
 							it != tl.end(); ++it )
 	{
 		if( solo )
@@ -2095,7 +2093,7 @@ void track::toggleSolo()
  *  \param _tcv The track Container View for us to be displayed in.
  *  \todo Is my description of these properties correct?
  */
-trackView::trackView( track * _track, trackContainerView * _tcv ) :
+trackView::trackView( track * _track, TrackContainerView * _tcv ) :
 	QWidget( _tcv->contentWidget() ),   /*!< The Track Container View's content widget. */
 	ModelView( NULL, this ),            /*!< The model view of this track */
 	m_track( _track ),                  /*!< The track we're displaying */
@@ -2222,7 +2220,7 @@ void trackView::modelChanged()
 	connect( m_track, SIGNAL( destroyedTrack() ), this, SLOT( close() ) );
 	m_trackOperationsWidget.m_muteBtn->setModel( &m_track->m_mutedModel );
 	m_trackOperationsWidget.m_soloBtn->setModel( &m_track->m_soloModel );
-	ModelView::modelChanged();	
+	ModelView::modelChanged();
 	setFixedHeight( m_track->getHeight() );
 }
 
@@ -2306,11 +2304,11 @@ void trackView::dropEvent( QDropEvent * _de )
 	if( type == ( "track_" + QString::number( m_track->type() ) ) )
 	{
 		// value contains our XML-data so simply create a
-		// multimediaProject which does the rest for us...
-		multimediaProject mmp( value.toUtf8() );
-		engine::getMixer()->lock();
-		m_track->restoreState( mmp.content().firstChild().toElement() );
-		engine::getMixer()->unlock();
+		// DataFile which does the rest for us...
+		DataFile dataFile( value.toUtf8() );
+		engine::mixer()->lock();
+		m_track->restoreState( dataFile.content().firstChild().toElement() );
+		engine::mixer()->unlock();
 		_de->accept();
 	}
 }
@@ -2405,10 +2403,12 @@ void trackView::mouseMoveEvent( QMouseEvent * _me )
 	else if( m_action == MoveTrack )
 	{
 		// look which track-widget the mouse-cursor is over
-		const trackView * track_at_y =
-			m_trackContainerView->trackViewAt(
-				mapTo( m_trackContainerView->contentWidget(),
-							_me->pos() ).y() );
+		const int y_pos = m_trackContainerView->contentWidget()->mapFromGlobal( _me->globalPos() ).y();
+		const trackView * track_at_y =	m_trackContainerView->trackViewAt( y_pos );
+
+// debug code
+//			qDebug( "y position %d", y_pos );
+			
 		// a track-widget not equal to ourself?
 		if( track_at_y != NULL && track_at_y != this )
 		{
